# UploadTestStatus


## Enum

* `FAILED` (value: `'FAILED'`)

* `BROKEN` (value: `'BROKEN'`)

* `PASSED` (value: `'PASSED'`)

* `SKIPPED` (value: `'SKIPPED'`)

* `UNKNOWN` (value: `'UNKNOWN'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


